@@ -5,7 +5,7 @@ generics::tidy
 #' Tidy a(n) lmtp object
 #'
 #' @param x A `lmtp` object produced by a call to [lmtp::lmtp_tmle()], [lmtp::lmtp_sdr()],
-#' [lmtp::lmtp_sub()], or [lmtp::lmtp_ipw()].
+#' [lmtp::lmtp_survival()].
 #' @param ... Unused, included for generic consistency only.
 #'
 #' @examples
@@ -19,12 +19,18 @@ generics::tidy
 #' }
 #'
 #' @export
-tidy.lmtp <- function(x, ...) {
-  out <- data.frame(estimator = x$estimator,
-                    estimate = x$theta,
-                    std.error = x$standard_error,
-                    conf.low = x$low,
-                    conf.high = x$high)
-  class(out) <- c("tbl_df", "tbl", "data.frame")
-  out
+tidy.lmtp <- function(x, ...) ife::tidy(x$estimate)
+
+#' Tidy a(n) lmtp_survival object
+#'
+#' @param x A `lmtp_survival` object produced by a call to [lmtp::lmtp_survival()].
+#' @param ... Unused, included for generic consistency only.
+#'
+#' @example inst/examples/lmtp_survival-ex.R
+#'
+#' @export
+tidy.lmtp_survival <- function(x, ...) {
+  out <- do.call("rbind", lapply(x, tidy))
+  out$time <- seq_along(x)
+  out[, c(ncol(out), 1:ncol(out) - 1)]
 }
